#
# spec file for package python-netmiko
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-netmiko
Version:        4.4.0
Release:        1.2
Summary:        Multi-vendor library to simplify Paramiko SSH connections to network devices
License:        MIT
URL:            https://github.com/ktbyers/netmiko
Source:         https://files.pythonhosted.org/packages/source/n/netmiko/netmiko-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module setuptools >= 65.0.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML >= 5.3
Requires:       python-cffi >= 1.17.0
Requires:       python-ntc-templates >= 3.1.0
Requires:       python-paramiko >= 2.9.5
Requires:       python-pyserial >= 3.3
Requires:       python-scp >= 0.13.6
Requires:       python-setuptools
Requires:       python-tenacity
Requires:       python-textfsm >= 1.1.3
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML >= 5.3}
BuildRequires:  %{python_module paramiko >= 2.6.0}
BuildRequires:  %{python_module pyserial >= 3.3}
BuildRequires:  %{python_module scp >= 0.13.2}
BuildRequires:  %{python_module textfsm >= 1.1.3}
# /SECTION
%python_subpackages

%description
Multi-vendor library to simplify Paramiko SSH connections to network devices.

%prep
%setup -q -n netmiko-%{version}
# drop shebang
sed -i -e '/^#!\//, 1d' \
  netmiko/nokia/nokia_sros.py \
  netmiko/cdot/cdot_cros_ssh.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/netmiko-cfg
%python_clone -a %{buildroot}%{_bindir}/netmiko-grep
%python_clone -a %{buildroot}%{_bindir}/netmiko-show
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# Fix python-bytecode-inconsistent-mtime
pushd %{buildroot}%{python_sitelib}
find . -name '*.pyc' -exec rm -f '{}' ';'
python%python_bin_suffix -m compileall *.py ';'
popd

%check
# NOTE: for testing, we have to manually run it against a given device.
#
# See https://github.com/ktbyers/netmiko/blob/develop/TESTING.md
#
# Unfortunately, we can't do that during build as those doesn't appeared
# to be unit tests.

%post
%python_install_alternative netmiko-cfg
%python_install_alternative netmiko-grep
%python_install_alternative netmiko-show

%postun
%python_uninstall_alternative netmiko-cfg
%python_uninstall_alternative netmiko-grep
%python_uninstall_alternative netmiko-show

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/netmiko-cfg
%python_alternative %{_bindir}/netmiko-grep
%python_alternative %{_bindir}/netmiko-show
%{python_sitelib}/netmiko
%{python_sitelib}/netmiko-%{version}.dist-info

%changelog
* Tue Oct  1 2024 Steve Kowalik <steven.kowalik@suse.com>
- Fix cffi version specifier, we are shipping a recent enough version.
* Tue Sep 24 2024 ecsos <ecsos@opensuse.org>
- Update to 4.4.0
  * New Drivers
  - Aruba AOS-CX
  * Other Major Changes
  - Add Python 3.13 support
  - Vendor telnetlib internally to Netmiko (PY3.13 dropped inclusion of telnetlib)
  * Other Improvements
  - Add save_config for Huawei VRPv8
  - Expand SSH autodetect support
  - Improvements for Sophos driver
  - Clean up log filter after disconnect
  - Improve IOS-XR exit_config_mode() behavior
* Tue Dec 12 2023 Dirk Müller <dmueller@suse.com>
- update to 4.3.0:
  * Netmiko's session_log has certain scenarios where it was
    failing to hide the default no_log items ("secret" and
    "password"). This bug has generally been fixed though there
    are likely edge scenarios where this could still happen.
    Given the nature of the session_log it should always be
    viewed as a security sensitive file.
  * Drop PY3.7 support
  * Improve Ciena SAOS logic in set_base_prompt
  * Improve Nokia SROS disable paging behavior
  * Remove Arris and Casa from SSH autodetect
  * Add support for Genie and Linux
  * Improve TP-Link session_preparation behavior
  * Improve MikoTik terminal size definition
  * Improve Arista SSH autodetection
  * Fix SNMP autodetection when hostname is used (instead of
    IPv4/IPv6 address)
  * Improve SCP behavior for remote_file_size when subdirectories
    are used
  * Implement TelnetFallback entry point
  * Improve Extreme SLX-OS autodetect
  * Improve Fortinet driver _get_output_mode_v6 behavior
  * Improve HP comware and HP procurve behavior in
    session_preparation
  * Add Allied Telesis in SNMP and SSH autodetect
  * Update hp_comware.py handle RBM in prompt
  * Update vyos_ssh.py to enter and exit config mode on save
  * Handle Huawei secure configuration message
  * Add support for a SessionLog object in dunder-init(). This
    allows a custom no_log definition.
  * CI-CD fixes for various things breaking
  * Improve ers driver cntl-y behavior
  * Adtran driver enable global_cmd_verify by default
  * Adtran driver improve enable() behavior
  * Add Telnet Proxy support for SOCKS Proxy
  * Add support for Fiberstore FSOS
  * Add support for Maipu
  * Add Digi TransPort Router Support
* Sun Aug 27 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 4.2.0
  Bug Fixes and Improvements
  * Expanded and improved SSH autodetect support.
  * Various bug fixes.
  * Improve Huawei driver.
  * MikroTik driver improvements.
  * Fortinet driver improvements.
  * IOS-XR driver improvements.
  * Add simpler solution for Paramiko disabled_algorithms issue.
  * Add IPv6 support for SNMP autodetect..
  * Convert over to use Poetry (eliminate setup.py).
  * Improve send_config_set() and read_timeout behavior.
  * Improve behavior of normalize_linefeeds() method. Add
    argument to disable this behavior.
  * Add check_state argument to enable() method that allows for
    disabling the initial check_enable_mode() call.
  New Drivers or Expanded Driver Support
  * Add support for Arris CER.
  * Add support for Casa CMTS.
  * Add support for Adva AOS FSP 150 F2 and F3.
  * Add support for Hillstone StoneOS.
  * Add support for Teldata CIT.
  * Add support for Cisco S200.
  * Add support for Ericsson MINI-LINK 66XX & 63XX.
  * Add support for SCP on Ubiquiti EdgeRouter.
* Mon Jul 10 2023 Matej Cepl <mcepl@suse.com>
- Clean up SPEC file.
* Thu Jul  6 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sun Sep 18 2022 Martin Hauke <mardnh@gmx.de>
- Update to 4.1.2:
  New Driver
  * Audiocode Driver.
  Bugs and Improvements
  * Improve disconnect behavior.
  * Improve encoding behavior.
  * Fix textfsm dependency issue by pinning to 1.1.2.
  * Proposed Cisco WLC fix for session_preparation().
  * Added Versa FlexVNF platform to SSH autodetect.
  * Nokia global_cmd_verify default fix.
  * Fix issue with redispatch not working due to no data.
  * Fix generator bug in send_config_set.
  * Fix to accommodate single character prompts in set_base_prompt.
  * Adding check that key_file exists if use_keys is True.
  * Minor session_log test updates.
* Tue Jul 19 2022 Dirk Müller <dmueller@suse.com>
- update to 4.1.1:
  * add Nokia SRLinux Support
  * Add Mikrotik File Transfer Support
  * Performance Improvements
  * Performance Improvements for Linux Driver
  * Improve Performance Graphs
  * Bug Fixes / Improvements
  * Better Error Messages for Incompatible Python Versions
  * Improve Huawei Driver
  * Improve Huawei VRPv8 Driver
  * Improve HPE ProCurve Driver
  * Improving Junos context stripping patterns
  * Improve MikroTik Driver
  * Fix for Extreme ERS login issues
  * Minor update to threading calls in Netmiko Tools
  * Increase save_config default timeout for Cisco-based platforms
* Wed Apr 27 2022 Martin Hauke <mardnh@gmx.de>
- Update to vedrsion 4.1.0
  Performance Improvements
  * Improve performance in Junos config_mode() and
    check_config_mode() methods.
  * Improve performance on disconnect() method.
  * Improve slow NX-OS disconnect()
  * Improve slow Junos disconnect()
  Bug Fixes and other Improvements
  * Update VyOS save_config()
  * Fix read_timeout being excessively long in case where
    check_config() fails
  * Fix Huawei regular expression issue
  * Fix Huawei login issue
  * Improve Juniper enter_cli_mode()
  * Fix issue with Nokia SROS MD-CLI having square bracket data
    being removed
  * Fix issue with 'write memory' on ubiquity edge switches
  * Fix extreme exos read-only account issue
  * Add Cisco WLC _send_command_w_yes() method
  * Fix Cisco IOS, IOS-XE, and IOS-XR abbreviating prompt in
    config mode
  * Fix Aruba controller paging issue
  * Fix fortigate autodetect
  * Fixing HP Procurve session_preparation issue on repeated
    connection
  Python Version Support
  * Remove PY3.6 Support
  * Add PY3.10 Support
* Wed Mar 30 2022 Martin Hauke <mardnh@gmx.de>
- Update to vedrsion 4.0.0
  Backwards incompatible and other major changes
  * Convert send_command to use read_timeout.
  * Convert send_command_timing to use read_timeout and last_read
  * Add type hints and mypy support
  * Relocate exceptions module to netmiko.exceptions (was
    ssh_exceptions)
  * Add read_timeout argument to send_config_set
  * Convert netmiko-tools to be an entry point and directly a part
    of Netmiko library
  * Creating a new internal Channel class
  * Restructure read methods
  * Implement NoEnable and NoConfig inheritance classes to
    standardize no-config and no-enable behavior
  Major new features
  * Add send_multiline() method
  * Add send_multiline_timing() method
  * Create new Netmiko factory function named ConnLogOnly
  * Create new Netmiko factory function named ConnUnify
  New Drivers
  * Cisco Viptela Driver
  * Dell SONiC Driver
  * Cisco S300 Telnet Driver
  * Allied Telesis AlliedWare Plus Driver
  * Zyxel Driver
  * Extreme Tierra OS Driver
  * Extreme EXOS Secure Copy Support
  Minor Enhancements
  * Centralize standard no_auth code into SSHClient_noauth
  * Remove vendored Textfsm library code
  * Add a shim for cisco_xe to use cisco_ios in ntc-templates
  * WLC add method send_command_w_yes to handle show command
    that still prompts for pagination
  * Platforms added to SSH autodetect
  * Expand ANSI escape code stripping
  * Expand SNMP autodetect support
  Bug Fixes
  * Fix read ahead issue with read methods
  * Fix ntc-templates directory structure issue
  * Aruba OS fix for hostname changes
  * Fix flexvnf enter cli and prompt issue
  * Mikrotik driver improvements and fixes
  * Fixing IOS-XR confirm prompting issue during commit
  * Fix the pan-os acknowledgment banner
  * Fix Juniper ScreenOS accept issue
  * Add support for Username: for telnet login on ProCurve
  * Change ArubaOS command to disable paging
  * utf-8 encoding for session_log
  * Add bypass_commands support to send_config_set to disable
    cmd_verify
  * Fix disconnect() call for Dlink DS driver
  * Prevent secret from being leaked to debug log
  * Fix send_command() read issue where data spanned the deque
  * Improve set_base_prompt behavior
  * Increase the default conn_timeout to 10 seconds improve
    Paramiko behavior on slow connections
  Performance Improvements
  * Fix IOS-XR performance issues
  * Implement Netmiko performance improvements for a large set
    of drivers (about half the drivers)
  * Fixing Linux very slow disconnect issue
* Sat Apr 24 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.4.0
  New Features
  * Add error_pattern argument to send_config_set() and
    send_config_from_file() to allow configuration to stop when
    pattern is detected.
  * Add run_ttp method to support more complex TTP interactions.
  * Juniper performance improvements.
  * ASA performance improvements.
  * Add telnet support to AdtranOS
  New Drivers
  * Allied Telesis AlliedWare Plus
  * Brocade Fabric OS
  * C-DOT CROS
  * Ericsson IPOS
  * Supermicro SMIS
  Bug fixes/improvements
  * Fixing Palo Alto line repaint issue
  * Fixing F5 TMSH disconnect process
  * Fix IOS-XR exit_config_mode issue
  * Fixing some enable method state issues
  * Fixing SR-OS remote file size
  * Fixing issue with remote_file_size parsing failure
  * Fix ASA enable() issue in session_preparation
  * Fix Yamaha enter issue on exit enable mode
  * Fix Yamaha telnet enter issue
  * F5 TMOS driver update
  * Fix newlines on Cisco NX-OS
  * Fixes an issue with ssh _autodetect_remote_version
  * Fix tplink_jetstream to support cryptography 3.1+
  * Allowing Dell OS10 to support hyphen or space
  * Fix authentication exception handling
  * Improve ssh_autodetect so most common command happens first.
  * Fix dell_force10 autodetect
* Tue Mar  2 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 3.3.3
  New Drivers
  * Add Ericcson IPOS Support
  * Adtran Telnet Support
  Performance Improvements
  * Juniper Performance Improvements
  * Cisco ASA Performance Improvements
  Bugs and Enhancements
  * Improve Authentication Exception Handling
  * FIX Cryptography Lib Change Issue
* Thu Oct  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.3.2
  New Features
  * Add support for PIP installable ntc-templates
  * Add support for TTP templates
  Performance Improvements
  * Cisco NX-OS Performance Improvements
  * Cisco IOS-XR Performance Improvements
  * Arista Performance Improvements
  New Drivers
  * Cisco FTD Driver
  * Ubiquity EdgeRouter
  * TPLink JetStream
  Bug Fixes
  * Secure Copy Progress Bar fix for get Operation
- Update to version 3.3.1
* Mon Aug 31 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.3.0
  * NewDriver: Netgear ProSafe
  * Minor change to Netgear Prosafe
  * Support for Adtran OS
  * Changed SSH terminal height in CiscoXrBase
  * XR commit comment change
  * Fix broken "enable" on Nokia SR-OS driver
  * Adding SR-OS to the tests
  * Fix WLC conn_timeout issue
  * Improve Session Preparation Behavior
  * Performance Improvements for IOS and IOS-XE
* Sat Aug  1 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.2.0
  * Fixing disable_paging and set_terminal_width so cmd_verify
    is not used as we are still in session_preparation phase.
  * Add Centec-switch platform
  * Sixwind Driver Update
  * Disable cmd_verify on Comware
  * check text with config_md5
  * Add support for vendor/os: broacom_icos.
  * Bypass automatic _open() call
  * Added HPE Comware support
  * Tell aruba connection to strip ansi codes from switches
  * Fixing Arista check_config_mode bug with hostname change
  * Ansi insert line for ProCurve and Aruba
  * Add progress bar for Secure Copy
  * Add connection timeout argument (conn_timeout)
* Tue May 19 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1.1
  New Drivers/Platforms
  * UnifiSwitchSSH
  * Huawei OLT
  * Huawei SmartAX
  Bugs and Improvements
  * Nokia SR-OS SCP Support
  * Improve terminal width behavior
  * Fix some issues related to cmd_verify
  * Expanded autodetect support
* Mon Mar 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1.0:
  New Platforms / Transports
  * D-Link DGS/DES
  * WatchGuard Firebox
  * Sophos SG Firewalls
  * Huawei Telnet Support
  Bug Fixes/Enhancements
  * Add cmd_verify argument to send_command
  * Add global_cmd_verify argument to ConnectHandler
* Thu Jan 16 2020 Martin Hauke <mardnh@gmx.de>
- Upate to version 3.0.0:
  Key enhancements/changes
  * PY3.6+ support only (all support for PY27 removed)
  * Significant reliability improvements to reduce loss of session
    state problems
  * Add support for direct use of TextFSM template
  * Allow custom socket timeout in SCP file_transfer
  * Improve MD5 hashing mechanism in SCP checks
  * Add sock parameter support
  * Increase default banner_timeout to 15
  New Drivers
  * Eltex ESR
  * Juniper ScreenOS
  * Ruijei RGOS
  Driver Updates
  * Huawei driver improvements
  * Ciena driver improvements
  * NX-OS driver improvements
  * Nokia SR-OS driver improvements
  * HP ProCurve driver improvements
  * Juniper Junos driver improvements
  * Fortinet banner fix
  * Ruckus handling of failed enable
  * Linux enable/sudo improvements
* Wed Sep 11 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.2:
  * Fix session_log corruption bug
  * Add support for ProxyJump in SSH config file
  * Add support for Linux prompt terminators via environment variables
* Tue Aug  6 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 2.4.1:
  * Add Genie/pyATS parser support
  * Fix Huawei telnet login
  * Fix support for TextFSM >= 1.0.0
  * Fixes on Mellanox Driver
* Fri Jul 12 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.0
  New Platforms
  * VERSA Networks FlexVNF
  * Mikrotik
  * CloudGenix ION
  * MRV LX
  * Endace
  * Huawei telnet support
  * IOS-XR telnet support
  Enhancements
  * Switch docs to pdoc3
  * Add support for paramiko banner_timeout
  * Netmiko Tools search path for inventory file
  Bug fixes
  * Fixing MD5 / carriage return issue on NX-OS 9K
  * Use YAML safe_load
  * Fix NET_TEXTFSM path issues
  * Update save_config method params across platforms
* Fri Mar  8 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.3
  * Add OneAccess OneOS Support
  * Use Python Black
  * Use environment markers for Poetry support
- Update to version 2.3.2
  * Removing obsolete development status
  * telnet return and return adjustments
  * fixed telnet not position
  * Add oneaccess SSH
  * Update tests for Oneaccss OneOS telnet + ssh;
  * Update Oneaccess OneOS telnet method
  * Add pattern for check_config_mode for cisco_ios and cisco_nxos
  * Ruckus FastIron/ICX telnet echo fix
  * Adding support for file transfer for different version of ios-xr
  * OneOS OneAccess set terminal width
  * Fixes #1028 incorrect parse ls output in error case
  * Allow support for Cisco WLC/AireOS grep include command
  * Updating to support kbytes for IOS-XR
  * Update IP in example code
  * Netscaler fix strip_prompt join.
  * Modified base_connection to check last 3 buffer reads for saved
    prompt.
  * adding blanket juniper statement to snmp auto detect
  * Update test suite to use isolated Arista vEOS
  * Fix ubiquity edge enable issue
  * Fix Python 3 serial driver issue.
  * Add QFabric and Brocade-Extreme NetIron and SLX Support in
    SSH Autodetect.
  * Fix commit issue on huawei
  * Fix Pala Alto not disconnecting gracefully
  * Add ubiquiti_edgeswitch to autodetect
  * Improve error message for WLC failure on initial 'login as'
    authentication.
* Wed Oct 10 2018 mardnh@gmx.de
- Update to version 2.3.0
  * Add Dell DNOS6 support
  * Add RAD ETX support
  * Add IP Infusion OcNOS support
  * Add Paramiko pkey, auth_timeout, and passphrase support.
  * Add support for unicode banners
  * Gracefully cleanup session on failures during session_preparation()
  * Bug fixes
* Thu Jul 19 2018 mardnh@gmx.de
- Update to version 2.2.2
  * Add Dell EMC Isilon Support
  * Add Citrix NetScaler Support
  * Add Dell OS10 Support
  * Add Apresia Systems AEOS Support
  * Add fast_cli mode to Netmiko to improve performance
  * Add support for a session_log
* Mon Jun 25 2018 gyee@suse.com
- Correct package name for python-PyYAML (case-sensitive)
* Thu Jun 21 2018 tchvatal@suse.com
- Use %%license not %%doc macro
* Wed Jun 20 2018 gyee@suse.com
- Remove devel as it is not needed.
* Wed Jun 20 2018 gyee@suse.com
- Remove pytest suggestion.
* Wed Jun 20 2018 gyee@suse.com
- Disable testing during build as those aren't unit tests. See
  See https://github.com/ktbyers/netmiko/blob/develop/TESTING.md
* Tue Jun 19 2018 gyee@suse.com
- Create python-netmiko package.
